@@ -15,6 +15,12 @@ __all__ = [
     "collect_model_tables",
     "model_copy_from",
     "make_base_model",
+    "SerialModelMixinProtocol",
+    "RecordModelMixinProtocol",
+    "SnapshotModelMixinProtocol",
+    "SerialModelMixin",
+    "RecordModelMixin",
+    "SnapshotModelMixin",
     "make_serial_model_mixin",
     "make_record_model_mixin",
     "make_snapshot_model_mixin",
@@ -127,11 +133,71 @@ def make_base_model() -> type[SQLModel]:
     return BaseModel
 
 
-class SerialModelMixinProto(Protocol):
+class SerialModelMixinProtocol(Protocol):
     sid: int | None
 
 
-def make_serial_model_mixin() -> type[SerialModelMixinProto]:
+class RecordModelMixinProtocol(Protocol):
+    sid: int | None
+    created_at: datetime.datetime | None
+    updated_at: datetime.datetime | None
+
+    @classmethod
+    def make_index_created_at(cls, index_name: str) -> sa.Index:
+        """
+        Helper to create an index on the `created_at` field with the given index name.
+        :param index_name: Name of the index to create.
+        :return: The created SQLAlchemy Index object.
+        """
+        ...
+
+
+class SnapshotModelMixinProtocol(Protocol):
+    sid: int | None
+    created_at: datetime.datetime | None
+    expired_at: datetime.datetime | None
+    record_sid: int | None
+
+    @classmethod
+    def make_index_created_at_expired_at(cls, index_name: str) -> sa.Index:
+        """
+        Helper to create an index on the `created_at` and `expired_at` fields with the given index name.
+        :param index_name: Name of the index to create.
+        :return: The created SQLAlchemy Index object.
+        """
+        ...
+
+    @classmethod
+    def make_active_unique_index_record_sid(cls, index_name: str) -> sa.Index:
+        """
+        Helper to create a unique index on the `record_sid` field for active records (where `expired_at` is NULL).
+        This ensures that there is only one active snapshot per record at any given time.
+        :param index_name: Name of the index to create.
+        :return: The created SQLAlchemy Index object.
+        """
+        ...
+
+    @classmethod
+    def make_active_unique_index_for(cls, index_name: str, *fields: str) -> sa.Index:
+        """
+        Helper to create a unique index on the specified fields for active records (where `expired_at` is NULL).
+        This ensures that there is only one active snapshot per combination of the specified fields at any given
+        time.
+        :param index_name: Name of the index to create.
+        :param fields: Fields to include in the unique index.
+        :return: The created SQLAlchemy Index object.
+        """
+        ...
+
+
+# At the present time, we cannot express intersection of Protocol and SQLModel directly.
+# Thus, we define union types here for the mixins.
+SerialModelMixin = SerialModelMixinProtocol | SQLModel
+RecordModelMixin = RecordModelMixinProtocol | SQLModel
+SnapshotModelMixin = SnapshotModelMixinProtocol | SQLModel
+
+
+def make_serial_model_mixin() -> type[SerialModelMixin]:
     """
     Creates a mixin class for SQLModel models that adds a unique identifier field `sid`.
     Use this mixin to add an auto-incremented primary key to your models.
@@ -147,22 +213,7 @@ def make_serial_model_mixin() -> type[SerialModelMixinProto]:
     return ModelMixin
 
 
-class RecordModelMixinProto(Protocol):
-    sid: int | None
-    created_at: datetime.datetime | None
-    updated_at: datetime.datetime | None
-
-    @classmethod
-    def make_index_created_at(cls, index_name: str) -> sa.Index:
-        """
-        Helper to create an index on the `created_at` field with the given index name.
-        :param index_name: Name of the index to create.
-        :return: The created SQLAlchemy Index object.
-        """
-        ...
-
-
-def make_record_model_mixin() -> type[RecordModelMixinProto]:
+def make_record_model_mixin() -> type[RecordModelMixin]:
     """
     Creates a mixin class for SQLModel models that adds common fields and validation logic for updatable records.
     This mixin includes `sid`, `created_at`, and `updated_at` fields, along with validation for timestamps.
@@ -213,45 +264,7 @@ def make_record_model_mixin() -> type[RecordModelMixinProto]:
     return ModelMixin
 
 
-class SnapshotModelMixinProto(Protocol):
-    sid: int | None
-    created_at: datetime.datetime | None
-    expired_at: datetime.datetime | None
-    record_sid: int | None
-
-    @classmethod
-    def make_index_created_at_expired_at(cls, index_name: str) -> sa.Index:
-        """
-        Helper to create an index on the `created_at` and `expired_at` fields with the given index name.
-        :param index_name: Name of the index to create.
-        :return: The created SQLAlchemy Index object.
-        """
-        ...
-
-    @classmethod
-    def make_active_unique_index_record_sid(cls, index_name: str) -> sa.Index:
-        """
-        Helper to create a unique index on the `record_sid` field for active records (where `expired_at` is NULL).
-        This ensures that there is only one active snapshot per record at any given time.
-        :param index_name: Name of the index to create.
-        :return: The created SQLAlchemy Index object.
-        """
-        ...
-
-    @classmethod
-    def make_active_unique_index_for(cls, index_name: str, *fields: str) -> sa.Index:
-        """
-        Helper to create a unique index on the specified fields for active records (where `expired_at` is NULL).
-        This ensures that there is only one active snapshot per combination of the specified fields at any given
-        time.
-        :param index_name: Name of the index to create.
-        :param fields: Fields to include in the unique index.
-        :return: The created SQLAlchemy Index object.
-        """
-        ...
-
-
-def make_snapshot_model_mixin() -> type[SnapshotModelMixinProto]:
+def make_snapshot_model_mixin() -> type[SnapshotModelMixin]:
     """
     Provides a mixin class for SQLModel models that adds common fields and validation logic for record snapshots.
     A snapshot model tracks the full change history of an entity: when any field changes, the current record (with a
