@@ -26,7 +26,7 @@ class DummyModel(make_base_model(), make_snapshot_model_mixin(), table=True):
 
     __table_args__ = (
         snapshot_model_mixin.make_index_created_at_expired_at("ix_dummy_model_created_at_expired_at"),
-        snapshot_model_mixin.make_active_unique_index_record_sid("aux_dummy_model_record_sid"),
+        snapshot_model_mixin.make_active_unique_index_record_sid("ix_au_dummy_model_record_sid"),
     )
 
 
